@@ -7,8 +7,7 @@ map2 <- bisonmap(out, tomap="county")
 map3 <- bisonmap(out, tomap="state")
 
 test_that("bisonmap returns the correct class", {
-  expect_is(map1, c("gg"))
-	expect_is(map1, c("ggplot","gg"))
-	expect_that(map2, is_a(c("ggplot","gg")))
-	expect_that(map3, is_a(c("ggplot","gg")))
-})
\ No newline at end of file
+  expect_is(map1$plot, "gg")
+  expect_is(map2, "gg")
+  expect_is(map3, "gg")
+})
